==> react-native-cometchat-calling-component-1.1.7.tgz: package/lib/JitsiManager.js <==
/* eslint-disable prettier/prettier */
(global => {
    if (typeof global.$ === 'undefined') {
        const jQuery = require('jquery');
        jQuery(global);
        global.$ = jQuery;
    }
})(global || window || this);


import '../native';
import { Component } from 'react';
import { Alert,NativeEventEmitter } from 'react-native';
import JitsiMeetJS from 'lib-jitsi-meet/lib-jitsi-meet.min';
import data from '../actions';
import AudioMode from '../AudioMode'
import Logger from './Logger';

export default class JitsiManager extends Component{

    static localVideoUrl = '';

    static roomName = null;

    static dispatch = null;

    static onMuteAudio (){
        JitsiManager.localTracks[0].mute();
    }
    
    static onUnmuteAudio (){
        JitsiManager.localTracks[0].unmute();
    }

    static onMuteVideo (){
         JitsiManager.localTracks[1].mute();
    }

    static onUnmuteVideo (){
        JitsiManager.localTracks[1].unmute();
    }

    static setAudioModeSpeaker(){
        AudioMode.setAudoSourceSpeaker();
    }

    static setAudioModeEarpiece(){
        AudioMode.setAudoSourceEarPiece();
    }

    static connection = null;

    static room = null;

    static localTracks = [];
    
    static isJoined = true;

    static callObject;

    static isInitiator;

    static users =[];

    static confOptions = {
        openBridgeChannel: true
    };

    static remoteTracks = {};

    static initOptions = {
        disableAudioLevels: true,
        desktopSharingChromeExtId: 'mbocklcggfhnbahlnepmldehdhpjfcjp',
        desktopSharingChromeDisabled: false,
        desktopSharingChromeSources: [ 'screen', 'window' ],
        desktopSharingChromeMinExtVersion: '0.1',
        desktopSharingFirefoxDisabled: true
    };

    static options = {
        hosts: {
          domain: 'rtc-us.cometchat.io',
          muc: 'conference.rtc-us.cometchat.io'
        },p2p: {
            enabled: true,
            stunServers: [
                { urls: 'stun:stun.l.google.com:19302' },
                { urls: 'stun:stun1.l.google.com:19302' },
                { urls: 'stun:stun2.l.google.com:19302' }
            ],
            preferH264: true
        },
        bosh: 'https://rtc-us.cometchat.io/http-bind',
        clientNode: 'http://jitsi.org/jitsimeet'
      };

    static eventEmitter = new NativeEventEmitter(AudioMode);

    static setCallObject(call,initiator){
        JitsiManager.callObject = call;
        JitsiManager.isInitiator = initiator;
    }

    static onConnectionSuccess(){
        JitsiManager.room = JitsiManager.connection.initJitsiConference(JitsiManager.roomName, JitsiManager.confOptions);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_ADDED, JitsiManager.onRemoteTrack);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_REMOVED, function(track){ console.info('track'); });
        JitsiManager.room.on(JitsiMeetJS.events.conference.CONFERENCE_JOINED, JitsiManager.onConferenceJoined);
        JitsiManager.room.on(JitsiMeetJS.events.conference.USER_JOINED, function(id) { 
            JitsiManager.eventEmitter.emit('CallEvent', { type: 'onConnectionSuccess' });
            if(JitsiManager.isInitiator){
                JitsiManager.room.sendCommand("CustomValueKEY1",{value: JitsiManager.callObject.callInitiator.uid});
            }else{
                JitsiManager.room.sendCommand("CustomValueKEY1",{value: JitsiManager.callObject.callReceiver.uid});
            }
        });
        JitsiManager.room.on(JitsiMeetJS.events.conference.USER_LEFT, JitsiManager.onUserLeft);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, function(track) { console.info('track'); });
        JitsiManager.room.on(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED, function (userID, displayName) {console.info('displayName')});
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED,function (userID, audioLevel) {console.info('audioLevel')});
        JitsiManager.room.addCommandListener("CustomValueKEY1", function (data){
            if(JitsiManager.users.indexOf(data.value) === -1){
                JitsiManager.users.push(data.value);
            }
        });
        JitsiManager.room.join();
    }

    static onLocalTracks = function(tracks) {
        JitsiManager.localTracks = tracks;
        JitsiManager.dispatch(data.addLocalTracks(JitsiManager.localTracks));        
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED, audioLevel => console.info('audioLevel'));
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED, function() {console.info('local track muted')});
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED,function () {console.info('track stopped')});
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED, deviceId => console.info('deviceId')); 
            if (JitsiManager.localTracks[i].getType() === 'video') {
                JitsiManager.dispatch(data.addLocalUrl(JitsiManager.localTracks[i].getOriginalStream().toURL()));
                JitsiManager.dispatch(data.addLocalTrackId(JitsiManager.localTracks[i].ownerEndpointId));    
            }
            if (!JitsiManager.isJoined) {
                JitsiManager.room.addTrack(JitsiManager.localTracks[i]);
            }
        }
    }

    static onCommandReceived(){

    }

    static onRemoteTrack = function(track) {
        if (track.isLocal()) {
            return;
        }
        JitsiManager.dispatch(data.addRemoteTracks(track));
        const participant = track.getParticipantId();
        if (!JitsiManager.remoteTracks[participant]) {
            JitsiManager.remoteTracks[participant] = [];
        }
        const idx = JitsiManager.remoteTracks[participant].push(track);
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED,audioLevel => console.info('audioLevel'));
        track.addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED,function() { console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED,function() {console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED,deviceId => console.info('deviceId'));
        const id = participant + track.getType() + idx;
        if (track.getType() === 'video') {
            JitsiManager.dispatch(data.addRemoteUrl(track.getOriginalStream().toURL()));
        } else {
            //$('.remoteVideo').append(`<audio autoplay='1' id='${participant}audio${idx}' />`);
        }
        //track.attach($('#'+id)[0]);
    }

    static onConferenceJoined = function() {
        JitsiManager.isJoined = true;
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            JitsiManager.room.addTrack(JitsiManager.localTracks[i]);
        }
    }

    static onUserLeft = function(id) {
        if (!JitsiManager.remoteTracks[id]) {
            return;
        }
        JitsiManager.dispatch(data.removeRemoteTrack(id));
        console.log("JitsiManager RemoteTracks length = ",JitsiManager.remoteTracks)
        //if(JitsiManager.remoteTracks.length == 0){
            JitsiManager.eventEmitter.emit('CallEvent', { type: 'EndCall' });
        //}
    }

    static onConnectionFailed = function() {
        Alert.alert(
            'Connection Failed',
            'There was a problem reaching our server. Please Try Again Later.',
            [{
                text: 'OK', 
                onPress: function() {JitsiManager.dispatch(data.connectionFailed(1))}
            }],
            {cancelable: false},
        );
    }

    static init = function(room) {
        JitsiManager.users = [];
        JitsiManager.roomName = room;
        JitsiMeetJS.init(JitsiManager.initOptions);
    }

    static makeConnection = function (){
        JitsiManager.connection = new JitsiMeetJS.JitsiConnection(null, null, JitsiManager.options);
        JitsiManager.connection.connect();
    }

    static disconnect = function() {      
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);
    }

    static addEventListener = function () {
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);
    }

    static createLocalTracks = function(dispatcher) {
        JitsiManager.dispatch = dispatcher;
        JitsiMeetJS.createLocalTracks({ devices: [ 'audio', 'video' ], facingMode: 'user' })
        .then(JitsiManager.onLocalTracks)
        .catch(error => {
            throw error;
        });
    }

    static onSwitchCamera = function() {
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            if(JitsiManager.localTracks[i].getType() === 'video'){
                JitsiManager.localTracks[i]._switchCamera();
            }
        }
    }
 
    static onHangUp = function() {
        if(JitsiManager.room){
            this.room.off(JitsiMeetJS.events.conference.TRACK_ADDED, JitsiManager.onRemoteTrack);
            this.room.off(JitsiMeetJS.events.conference.TRACK_REMOVED, track => { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.CONFERENCE_JOINED, JitsiManager.onConferenceJoined);
            this.room.off(JitsiMeetJS.events.conference.USER_JOINED, id => { JitsiManager.remoteTracks[id] = []; });
            this.room.off(JitsiMeetJS.events.conference.USER_LEFT, JitsiManager.onUserLeft);
            this.room.off(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, track => { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED,function (userID, displayName) {console.info('displayName')});
            this.room.off(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED, function (userID, audioLevel) {console.info('audioLevel')});
            this.room.leave().catch(function (e) {
                //console.log(e)
            });
            this.room = null;
        }
        
        if (this.connection) {
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);    
            this.connection.disconnect();
            this.connection = null;
        }
        if(this.dispatch !== null){
            this.dispatch(data.removeLocalTracks());
            this.dispatch(data.removeRemoteTracks());
            this.dispatch(data.addLocalUrl(''));
            this.dispatch(data.addRemoteUrl(''));
        }

        JitsiManager.eventEmitter.emit('CallEvent', { type: 'EndCall' });
    }
}

==> react-native-cometchat-calling-component-1.1.14.tgz: package/lib/JitsiManager.js <==
/* eslint-disable prettier/prettier */
(global => {
    if (typeof global.$ === 'undefined') {
        const jQuery = require('jquery');
        jQuery(global);
        global.$ = jQuery;
    }
})(global || window || this);


import '../native';
import { Component } from 'react';
import { Alert,NativeEventEmitter } from 'react-native';
import JitsiMeetJS from 'lib-jitsi-meet/lib-jitsi-meet.min';
import data from '../actions';
import AudioMode from '../AudioMode'
import Logger from './Logger';

export default class JitsiManager extends Component{

    static localVideoUrl = '';

    static roomName = null;

    static dispatch = null;

    static onMuteAudio (){
        JitsiManager.localTracks[0].mute();
    }
    
    static onUnmuteAudio (){
        JitsiManager.localTracks[0].unmute();
    }

    static onMuteVideo (){
         JitsiManager.localTracks[1].mute();
    }

    static onUnmuteVideo (){
        JitsiManager.localTracks[1].unmute();
    }

    static setAudioModeSpeaker(){
        AudioMode.setAudoSourceSpeaker();
    }

    static setAudioModeEarpiece(){
        AudioMode.setAudoSourceEarPiece();
    }

    static connection = null;

    static room = null;

    static localTracks = [];
    
    static isJoined = true;

    static userObject;

    static receiverObject;

    static isInitiator;

    static users =[];

    static removedTracks =[];

    static confOptions = {
        openBridgeChannel: false
    };

    static remoteTracks = {};

    static initOptions = {
        disableAudioLevels: true,
        desktopSharingChromeExtId: 'mbocklcggfhnbahlnepmldehdhpjfcjp',
        desktopSharingChromeDisabled: false,
        desktopSharingChromeSources: [ 'screen', 'window' ],
        desktopSharingChromeMinExtVersion: '0.1',
        desktopSharingFirefoxDisabled: true
    };

    static options = {
        hosts: {
          domain: 'rtc-us.cometchat.io',
          muc: 'conference.rtc-us.cometchat.io'
        },p2p: {
            enabled: true,
            stunServers: [
                { urls: 'stun:stun.l.google.com:19302' },
                { urls: 'stun:stun1.l.google.com:19302' },
                { urls: 'stun:stun2.l.google.com:19302' }
            ],
            preferH264: true
        },
        bosh: 'https://rtc-us.cometchat.io/http-bind',
        clientNode: 'http://jitsi.org/jitsimeet'
      };

    static eventEmitter = new NativeEventEmitter(AudioMode);

    static setCallObject(user,receiver,initiator){
        JitsiManager.isInitiator = initiator;
        JitsiManager.receiverObject = receiver;
        JitsiManager.userObject = user;
    }

    static onConnectionSuccess(){
        Logger.log("onConnectionSuccess Called");
        JitsiManager.room = JitsiManager.connection.initJitsiConference(JitsiManager.roomName, JitsiManager.confOptions);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_ADDED, JitsiManager.onRemoteTrack);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_REMOVED,JitsiManager.onTrackRemoved);
        JitsiManager.room.on(JitsiMeetJS.events.conference.CONFERENCE_JOINED, JitsiManager.onConferenceJoined);
        JitsiManager.room.on(JitsiMeetJS.events.conference.USER_JOINED, function(id) { 
            Logger.log("On USER_JOINED ID : ",id);
            JitsiManager.eventEmitter.emit('CallEvent', { type: 'onConnectionSuccess' });
            Logger.log("RTCUserUid",JitsiManager.userObject.uid)
            JitsiManager.room.sendCommand("RTCUserUid",{attributes:{uid:JitsiManager.userObject.uid,name:JitsiManager.userObject.name,avatar:JitsiManager.userObject.avatar,trackid:id}});
        });
        JitsiManager.room.on(JitsiMeetJS.events.conference.USER_LEFT, JitsiManager.onUserLeft);
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, function(track) { console.info('track'); });
        JitsiManager.room.on(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED, function (userID, displayName) {console.info('displayName')});
        JitsiManager.room.on(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED,function (userID, audioLevel) {console.info('audioLevel')});
        JitsiManager.room.addCommandListener("RTCUserUid", function (data){
            Logger.log("RTCUserUid Attributes Received ",data.attributes)
            var i;
            var userExists = false;
            for(i=0;i<JitsiManager.users.length;i++){
                if(data.attributes.uid == JitsiManager.users[i].uid){
                    userExists = true;
                }
            }
            if(!userExists){
                JitsiManager.users.push(data.attributes);
            }
        });
        JitsiManager.room.join();
    }

    static onLocalTracks = function(tracks) {
        JitsiManager.localTracks = tracks;
        JitsiManager.dispatch(data.addLocalTracks(JitsiManager.localTracks));        
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED, audioLevel => console.info('audioLevel'));
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED, function() {console.info('local track muted')});
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED,function () {console.info('track stopped')});
            JitsiManager.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED, deviceId => console.info('deviceId')); 
            if (JitsiManager.localTracks[i].getType() === 'video') {
                JitsiManager.dispatch(data.addLocalUrl(JitsiManager.localTracks[i].getOriginalStream().toURL()));
                JitsiManager.dispatch(data.addLocalTrackId(JitsiManager.localTracks[i].ownerEndpointId));    
            }
            if (!JitsiManager.isJoined) {
                JitsiManager.room.addTrack(JitsiManager.localTracks[i]);
            }
        }
    }

    static onTrackRemoved = function(track) {
        Logger.log("onTrackRemoved Called for owner id ",track.ownerEndpointId);
        Logger.log("onTrackRemoved Called ",track);
        Logger.log("Track eventCount ",track._eventsCount);
        
        var id = track.ownerEndpointId;
        if (track.isLocal()) {
            return;
        }
        // if (!JitsiManager.remoteTracks[id]) {
        //     return;
        // }
        JitsiManager.removedTracks.push(id);
        JitsiManager.dispatch(data.removeRemoteTrack(id));
    }

    static onRemoteTrack = function(track) {
        Logger.log("onRemoteTrack Called for track id ",track.ownerEndpointId);
        if (track.isLocal()) {
            return;
        }

        // if(JitsiManager.removedTracks.indexOf(track.ownerEndpointId) > -1){
        //     Logger.log("onRemoteTrack adding removed track ");
        //     return;
        // }
        JitsiManager.dispatch(data.addRemoteTracks(track));
        const participant = track.getParticipantId();
        if (!JitsiManager.remoteTracks[participant]) {
            JitsiManager.remoteTracks[participant] = [];
        }
        const idx = JitsiManager.remoteTracks[participant].push(track);
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED,audioLevel => console.info('audioLevel'));
        track.addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED,function() { console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED,function() {console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED,deviceId => console.info('deviceId'));
        const id = participant + track.getType() + idx;
        if (track.getType() === 'video') {
            JitsiManager.dispatch(data.addRemoteUrl(track.getOriginalStream().toURL()));
        } else {
            //$('.remoteVideo').append(`<audio autoplay='1' id='${participant}audio${idx}' />`);
        }
        //track.attach($('#'+id)[0]);
    }

    static onConferenceJoined = function() {
        JitsiManager.isJoined = true;
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            JitsiManager.room.addTrack(JitsiManager.localTracks[i]);
        }
    }

    static onUserLeft = function(id) {
        Logger.log("onUserLeft id lol : ",id);
        if (!JitsiManager.remoteTracks[id]) {
            return;
        }
        JitsiManager.dispatch(data.removeRemoteTrack(id));
        for( var i = 0; i < JitsiManager.users.length; i++){ 
            if(JitsiManager.users[i].trackid === id){
                JitsiManager.users.splice(i,1);
            }
        }
        if(JitsiManager.users.length <= 1){
            JitsiManager.eventEmitter.emit('CallEvent', { type: 'EndCall' });
        }
    }

    static onConnectionFailed = function() {
        Alert.alert(
            'Connection Failed',
            'There was a problem reaching our server. Please Try Again Later.',
            [{
                text: 'OK', 
                onPress: function() {JitsiManager.dispatch(data.connectionFailed(1))}
            }],
            {cancelable: false},
        );
    }

    static init = function(room) {
        Logger.log("Init called");
        JitsiManager.users = [];
        JitsiManager.roomName = room;
        JitsiMeetJS.init(JitsiManager.initOptions);
        JitsiMeetJS.setLogLevel(JitsiMeetJS.logLevels.ERROR);
    }

    static makeConnection = function (){
        Logger.log("makeConnection called");
        JitsiManager.connection = new JitsiMeetJS.JitsiConnection(null, null, JitsiManager.options);
        JitsiManager.connection.connect();
    }

    static disconnect = function() {      
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);
    }

    static addEventListener = function () {
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);
    }

    static createLocalTracks = function(dispatcher) {
        Logger.log("Create Local track called");
        JitsiManager.dispatch = dispatcher;
        JitsiMeetJS.createLocalTracks({ devices: [ 'audio', 'video' ], facingMode: 'user' })
        .then(JitsiManager.onLocalTracks)
        .catch(error => {
            Logger.log("Create Local Track called..");
            throw error;
        });
    }

    static onSwitchCamera = function() {
        for (let i = 0; i < JitsiManager.localTracks.length; i++) {
            if(JitsiManager.localTracks[i].getType() === 'video'){
                JitsiManager.localTracks[i]._switchCamera();
            }
        }
    }
 
    static onHangUp = function() {
        Logger.log("onHangup Called");
        if(JitsiManager.room){
            this.room.off(JitsiMeetJS.events.conference.TRACK_ADDED, JitsiManager.onRemoteTrack);
            this.room.off(JitsiMeetJS.events.conference.TRACK_REMOVED, track => { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.CONFERENCE_JOINED, JitsiManager.onConferenceJoined);
            this.room.off(JitsiMeetJS.events.conference.USER_JOINED, id => { JitsiManager.remoteTracks[id] = []; });
            this.room.off(JitsiMeetJS.events.conference.USER_LEFT, JitsiManager.onUserLeft);
            this.room.off(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, track => { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED,function (userID, displayName) {console.info('displayName')});
            this.room.off(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED, function (userID, audioLevel) {console.info('audioLevel')});
            this.room.leave().catch(function (e) {
                //console.log(e)
            });
            this.room = null;
        }
        
        if (this.connection) {
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, JitsiManager.onConnectionSuccess);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, JitsiManager.onConnectionFailed);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, JitsiManager.disconnect);    
            this.connection.disconnect();
            this.connection = null;
        }
        if(this.dispatch !== null){
            this.dispatch(data.removeLocalTracks());
            this.dispatch(data.removeRemoteTracks());
            this.dispatch(data.addLocalUrl(''));
            this.dispatch(data.addRemoteUrl(''));
        }

        JitsiManager.eventEmitter.emit('CallEvent', { type: 'EndCall' });
    }
}
